@@ -1,12 +1,22 @@
+import platform
 from pathlib import Path
+from unittest import mock
 from unittest.mock import patch
 
 import aiohttp
+from aiohttp import ClientTimeout
+from aiohttp.test_utils import AioHTTPTestCase, unittest_run_loop
+
 import pytest
 from pytest_localserver.http import WSGIServer
-
 from parfive.downloader import Downloader, Token, FailedDownload, Results
+from parfive.utils import sha256sum
+import parfive
+import sys
+import os
+import hashlib
 
+skip_windows = pytest.mark.skipif(platform.system() == 'Windows', reason="Windows.")
 
 def test_setup(event_loop):
     dl = Downloader(loop=event_loop)
@@ -25,6 +35,23 @@ def test_download(event_loop, httpserver, tmpdir):
                              headers={'Content-Disposition': "attachment; filename=testfile.fits"})
     dl = Downloader(loop=event_loop)
 
+    dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
+
+    assert dl.queued_downloads == 1
+
+    f = dl.download()
+
+    assert len(f) == 1
+    assert Path(f[0]).name == "testfile.fits"
+    assert sha256sum(f[0]) == "a1c58cd340e3bd33f94524076f1fa5cf9a7f13c59d5272a9d4bc0b5bc436d9b3"
+
+
+def test_download_ranged_http(event_loop, httpserver, tmpdir):
+    tmpdir = str(tmpdir)
+    httpserver.serve_content('SIMPLE  = T',
+                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    dl = Downloader(loop=event_loop)
+
     dl.enqueue_file(httpserver.url, path=Path(tmpdir))
 
     assert dl.queued_downloads == 1
@@ -33,6 +60,7 @@ def test_download(event_loop, httpserver, tmpdir):
 
     assert len(f) == 1
     assert Path(f[0]).name == "testfile.fits"
+    assert sha256sum(f[0]) == "a1c58cd340e3bd33f94524076f1fa5cf9a7f13c59d5272a9d4bc0b5bc436d9b3"
 
 
 def test_download_partial(event_loop, httpserver, tmpdir):
@@ -144,7 +172,7 @@ def test_download_unique(event_loop, httpserver, tmpdir):
 
     for fn in f:
         assert fn not in filenames
-        assert "{fname}.1".format(fname=fname) in fn
+        assert f"{fname}.1" in fn
 
 
 @pytest.fixture
@@ -160,7 +188,7 @@ def testserver(request):
         if counter != 2:
             status = '200 OK'
             response_headers = [('Content-type', 'text/plain'),
-                                ('Content-Disposition', ('testfile_{}'.format(counter)))]
+                                ('Content-Disposition', (f'testfile_{counter}'))]
             start_response(status, response_headers)
             return [b'Hello world!\n']
         else:
@@ -289,6 +317,7 @@ def test_empty_retry():
     dl.retry(f)
 
 
+@skip_windows
 @pytest.mark.allow_hosts(True)
 def test_ftp(tmpdir):
     tmpdir = str(tmpdir)
@@ -304,6 +333,7 @@ def test_ftp(tmpdir):
     assert len(f.errors) == 3
 
 
+@skip_windows
 @pytest.mark.allow_hosts(True)
 def test_ftp_http(tmpdir, httpserver):
     tmpdir = str(tmpdir)
@@ -325,10 +355,57 @@ def test_ftp_http(tmpdir, httpserver):
     assert len(f.errors) == 4
 
 
-def test_handling_future_version_kwargs(tmpdir):
+def test_default_user_agent(event_loop, httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    dl = Downloader()
-    dl.enqueue_file("http://notaurl.notadomain/notafile", path=tmpdir, max_splits=5)
+    httpserver.serve_content('SIMPLE  = T',
+                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+
+    dl = Downloader(loop=event_loop)
+    dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
 
     assert dl.queued_downloads == 1
-    assert 'max_splits' not in dl.http_queue._queue[0].keywords.keys()
+
+    dl.download()
+
+    assert 'User-Agent' in httpserver.requests[0].headers
+    assert httpserver.requests[0].headers['User-Agent'] == f"parfive/{parfive.__version__} aiohttp/{aiohttp.__version__} python/{sys.version[:5]}"
+
+
+def test_custom_user_agent(event_loop, httpserver, tmpdir):
+    tmpdir = str(tmpdir)
+    httpserver.serve_content('SIMPLE  = T',
+                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+
+    dl = Downloader(loop=event_loop, headers={'User-Agent': 'test value 299792458'})
+    dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
+
+    assert dl.queued_downloads == 1
+
+    dl.download()
+
+    assert 'User-Agent' in httpserver.requests[0].headers
+    assert httpserver.requests[0].headers['User-Agent'] == "test value 299792458"
+
+
+@patch.dict(os.environ, {'HTTP_PROXY': "http_proxy_url",'HTTPS_PROXY': "https_proxy_url"})
+@pytest.mark.parametrize("url,proxy",[('http://test.example.com','http_proxy_url'),('https://test.example.com','https_proxy_url')])
+def test_proxy_passed_as_kwargs_to_get(event_loop, tmpdir, url, proxy):
+
+    with mock.patch(
+                    "aiohttp.client.ClientSession._request",
+                    new_callable=mock.MagicMock
+                   ) as patched:
+
+        dl = Downloader(loop=event_loop)
+        dl.enqueue_file(url, path=Path(tmpdir), max_splits=None)
+
+        assert dl.queued_downloads == 1
+
+        dl.download()
+
+    assert patched.called, "`ClientSession._request` not called"
+    assert list(patched.call_args) == [('GET', url),
+                                       {'allow_redirects': True, 
+                                        'timeout': ClientTimeout(total=300, connect=None, sock_read=90, sock_connect=None),
+                                        'proxy': proxy
+                                       }]
