@@ -1,4 +1,5 @@
 import cgi
+import hashlib
 import pathlib
 from itertools import count
 
@@ -87,7 +88,7 @@ def replacement_filename(path):
             name, _ = path.name.split(suffix)
         else:
             name = path.name
-        new_name = "{name}.{c}{suffix}".format(name=name, c=c, suffix=suffix)
+        new_name = f"{name}.{c}{suffix}"
         new_path = path.parent / new_name
         if not new_path.exists():
             return new_path
@@ -113,6 +114,19 @@ def get_filepath(filepath, overwrite):
     return filepath, False
 
 
+def sha256sum(filename):
+    """
+    https://stackoverflow.com/a/44873382
+    """
+    h  = hashlib.sha256()
+    b  = bytearray(128*1024)
+    mv = memoryview(b)
+    with open(filename, 'rb', buffering=0) as f:
+        for n in iter(lambda : f.readinto(mv), 0):
+            h.update(mv[:n])
+    return h.hexdigest()
+
+
 class FailedDownload(Exception):
     def __init__(self, filepath_partial, url, exception):
         self.filepath_partial = filepath_partial
@@ -122,7 +136,7 @@ class FailedDownload(Exception):
 
     def __repr__(self):
         out = super().__repr__()
-        out += '\n {} {}'.format(self.url, self.exception)
+        out += f'\n {self.url} {self.exception}'
         return out
 
     def __str__(self):
@@ -134,7 +148,7 @@ class Token:
         self.n = n
 
     def __repr__(self):
-        return super().__repr__() + "n = {}".format(self.n)
+        return super().__repr__() + f"n = {self.n}"
 
     def __str__(self):
-        return "Token {}".format(self.n)
+        return f"Token {self.n}"
